# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _H2ONaCl
else:
    import _H2ONaCl

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _H2ONaCl.delete_SwigPyIterator

    def value(self):
        return _H2ONaCl.SwigPyIterator_value(self)

    def incr(self, n=1):
        return _H2ONaCl.SwigPyIterator_incr(self, n)

    def decr(self, n=1):
        return _H2ONaCl.SwigPyIterator_decr(self, n)

    def distance(self, x):
        return _H2ONaCl.SwigPyIterator_distance(self, x)

    def equal(self, x):
        return _H2ONaCl.SwigPyIterator_equal(self, x)

    def copy(self):
        return _H2ONaCl.SwigPyIterator_copy(self)

    def next(self):
        return _H2ONaCl.SwigPyIterator_next(self)

    def __next__(self):
        return _H2ONaCl.SwigPyIterator___next__(self)

    def previous(self):
        return _H2ONaCl.SwigPyIterator_previous(self)

    def advance(self, n):
        return _H2ONaCl.SwigPyIterator_advance(self, n)

    def __eq__(self, x):
        return _H2ONaCl.SwigPyIterator___eq__(self, x)

    def __ne__(self, x):
        return _H2ONaCl.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n):
        return _H2ONaCl.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n):
        return _H2ONaCl.SwigPyIterator___isub__(self, n)

    def __add__(self, n):
        return _H2ONaCl.SwigPyIterator___add__(self, n)

    def __sub__(self, *args):
        return _H2ONaCl.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _H2ONaCl:
_H2ONaCl.SwigPyIterator_swigregister(SwigPyIterator)

class IntVector(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _H2ONaCl.IntVector_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _H2ONaCl.IntVector___nonzero__(self)

    def __bool__(self):
        return _H2ONaCl.IntVector___bool__(self)

    def __len__(self):
        return _H2ONaCl.IntVector___len__(self)

    def __getslice__(self, i, j):
        return _H2ONaCl.IntVector___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _H2ONaCl.IntVector___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _H2ONaCl.IntVector___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _H2ONaCl.IntVector___delitem__(self, *args)

    def __getitem__(self, *args):
        return _H2ONaCl.IntVector___getitem__(self, *args)

    def __setitem__(self, *args):
        return _H2ONaCl.IntVector___setitem__(self, *args)

    def pop(self):
        return _H2ONaCl.IntVector_pop(self)

    def append(self, x):
        return _H2ONaCl.IntVector_append(self, x)

    def empty(self):
        return _H2ONaCl.IntVector_empty(self)

    def size(self):
        return _H2ONaCl.IntVector_size(self)

    def swap(self, v):
        return _H2ONaCl.IntVector_swap(self, v)

    def begin(self):
        return _H2ONaCl.IntVector_begin(self)

    def end(self):
        return _H2ONaCl.IntVector_end(self)

    def rbegin(self):
        return _H2ONaCl.IntVector_rbegin(self)

    def rend(self):
        return _H2ONaCl.IntVector_rend(self)

    def clear(self):
        return _H2ONaCl.IntVector_clear(self)

    def get_allocator(self):
        return _H2ONaCl.IntVector_get_allocator(self)

    def pop_back(self):
        return _H2ONaCl.IntVector_pop_back(self)

    def erase(self, *args):
        return _H2ONaCl.IntVector_erase(self, *args)

    def __init__(self, *args):
        _H2ONaCl.IntVector_swiginit(self, _H2ONaCl.new_IntVector(*args))

    def push_back(self, x):
        return _H2ONaCl.IntVector_push_back(self, x)

    def front(self):
        return _H2ONaCl.IntVector_front(self)

    def back(self):
        return _H2ONaCl.IntVector_back(self)

    def assign(self, n, x):
        return _H2ONaCl.IntVector_assign(self, n, x)

    def resize(self, *args):
        return _H2ONaCl.IntVector_resize(self, *args)

    def insert(self, *args):
        return _H2ONaCl.IntVector_insert(self, *args)

    def reserve(self, n):
        return _H2ONaCl.IntVector_reserve(self, n)

    def capacity(self):
        return _H2ONaCl.IntVector_capacity(self)
    __swig_destroy__ = _H2ONaCl.delete_IntVector

# Register IntVector in _H2ONaCl:
_H2ONaCl.IntVector_swigregister(IntVector)

class DoubleVector(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _H2ONaCl.DoubleVector_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _H2ONaCl.DoubleVector___nonzero__(self)

    def __bool__(self):
        return _H2ONaCl.DoubleVector___bool__(self)

    def __len__(self):
        return _H2ONaCl.DoubleVector___len__(self)

    def __getslice__(self, i, j):
        return _H2ONaCl.DoubleVector___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _H2ONaCl.DoubleVector___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _H2ONaCl.DoubleVector___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _H2ONaCl.DoubleVector___delitem__(self, *args)

    def __getitem__(self, *args):
        return _H2ONaCl.DoubleVector___getitem__(self, *args)

    def __setitem__(self, *args):
        return _H2ONaCl.DoubleVector___setitem__(self, *args)

    def pop(self):
        return _H2ONaCl.DoubleVector_pop(self)

    def append(self, x):
        return _H2ONaCl.DoubleVector_append(self, x)

    def empty(self):
        return _H2ONaCl.DoubleVector_empty(self)

    def size(self):
        return _H2ONaCl.DoubleVector_size(self)

    def swap(self, v):
        return _H2ONaCl.DoubleVector_swap(self, v)

    def begin(self):
        return _H2ONaCl.DoubleVector_begin(self)

    def end(self):
        return _H2ONaCl.DoubleVector_end(self)

    def rbegin(self):
        return _H2ONaCl.DoubleVector_rbegin(self)

    def rend(self):
        return _H2ONaCl.DoubleVector_rend(self)

    def clear(self):
        return _H2ONaCl.DoubleVector_clear(self)

    def get_allocator(self):
        return _H2ONaCl.DoubleVector_get_allocator(self)

    def pop_back(self):
        return _H2ONaCl.DoubleVector_pop_back(self)

    def erase(self, *args):
        return _H2ONaCl.DoubleVector_erase(self, *args)

    def __init__(self, *args):
        _H2ONaCl.DoubleVector_swiginit(self, _H2ONaCl.new_DoubleVector(*args))

    def push_back(self, x):
        return _H2ONaCl.DoubleVector_push_back(self, x)

    def front(self):
        return _H2ONaCl.DoubleVector_front(self)

    def back(self):
        return _H2ONaCl.DoubleVector_back(self)

    def assign(self, n, x):
        return _H2ONaCl.DoubleVector_assign(self, n, x)

    def resize(self, *args):
        return _H2ONaCl.DoubleVector_resize(self, *args)

    def insert(self, *args):
        return _H2ONaCl.DoubleVector_insert(self, *args)

    def reserve(self, n):
        return _H2ONaCl.DoubleVector_reserve(self, n)

    def capacity(self):
        return _H2ONaCl.DoubleVector_capacity(self)
    __swig_destroy__ = _H2ONaCl.delete_DoubleVector

# Register DoubleVector in _H2ONaCl:
_H2ONaCl.DoubleVector_swigregister(DoubleVector)

class StringVector(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _H2ONaCl.StringVector_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _H2ONaCl.StringVector___nonzero__(self)

    def __bool__(self):
        return _H2ONaCl.StringVector___bool__(self)

    def __len__(self):
        return _H2ONaCl.StringVector___len__(self)

    def __getslice__(self, i, j):
        return _H2ONaCl.StringVector___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _H2ONaCl.StringVector___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _H2ONaCl.StringVector___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _H2ONaCl.StringVector___delitem__(self, *args)

    def __getitem__(self, *args):
        return _H2ONaCl.StringVector___getitem__(self, *args)

    def __setitem__(self, *args):
        return _H2ONaCl.StringVector___setitem__(self, *args)

    def pop(self):
        return _H2ONaCl.StringVector_pop(self)

    def append(self, x):
        return _H2ONaCl.StringVector_append(self, x)

    def empty(self):
        return _H2ONaCl.StringVector_empty(self)

    def size(self):
        return _H2ONaCl.StringVector_size(self)

    def swap(self, v):
        return _H2ONaCl.StringVector_swap(self, v)

    def begin(self):
        return _H2ONaCl.StringVector_begin(self)

    def end(self):
        return _H2ONaCl.StringVector_end(self)

    def rbegin(self):
        return _H2ONaCl.StringVector_rbegin(self)

    def rend(self):
        return _H2ONaCl.StringVector_rend(self)

    def clear(self):
        return _H2ONaCl.StringVector_clear(self)

    def get_allocator(self):
        return _H2ONaCl.StringVector_get_allocator(self)

    def pop_back(self):
        return _H2ONaCl.StringVector_pop_back(self)

    def erase(self, *args):
        return _H2ONaCl.StringVector_erase(self, *args)

    def __init__(self, *args):
        _H2ONaCl.StringVector_swiginit(self, _H2ONaCl.new_StringVector(*args))

    def push_back(self, x):
        return _H2ONaCl.StringVector_push_back(self, x)

    def front(self):
        return _H2ONaCl.StringVector_front(self)

    def back(self):
        return _H2ONaCl.StringVector_back(self)

    def assign(self, n, x):
        return _H2ONaCl.StringVector_assign(self, n, x)

    def resize(self, *args):
        return _H2ONaCl.StringVector_resize(self, *args)

    def insert(self, *args):
        return _H2ONaCl.StringVector_insert(self, *args)

    def reserve(self, n):
        return _H2ONaCl.StringVector_reserve(self, n)

    def capacity(self):
        return _H2ONaCl.StringVector_capacity(self)
    __swig_destroy__ = _H2ONaCl.delete_StringVector

# Register StringVector in _H2ONaCl:
_H2ONaCl.StringVector_swigregister(StringVector)

class ConstCharVector(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _H2ONaCl.ConstCharVector_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _H2ONaCl.ConstCharVector___nonzero__(self)

    def __bool__(self):
        return _H2ONaCl.ConstCharVector___bool__(self)

    def __len__(self):
        return _H2ONaCl.ConstCharVector___len__(self)

    def __getslice__(self, i, j):
        return _H2ONaCl.ConstCharVector___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _H2ONaCl.ConstCharVector___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _H2ONaCl.ConstCharVector___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _H2ONaCl.ConstCharVector___delitem__(self, *args)

    def __getitem__(self, *args):
        return _H2ONaCl.ConstCharVector___getitem__(self, *args)

    def __setitem__(self, *args):
        return _H2ONaCl.ConstCharVector___setitem__(self, *args)

    def pop(self):
        return _H2ONaCl.ConstCharVector_pop(self)

    def append(self, x):
        return _H2ONaCl.ConstCharVector_append(self, x)

    def empty(self):
        return _H2ONaCl.ConstCharVector_empty(self)

    def size(self):
        return _H2ONaCl.ConstCharVector_size(self)

    def swap(self, v):
        return _H2ONaCl.ConstCharVector_swap(self, v)

    def begin(self):
        return _H2ONaCl.ConstCharVector_begin(self)

    def end(self):
        return _H2ONaCl.ConstCharVector_end(self)

    def rbegin(self):
        return _H2ONaCl.ConstCharVector_rbegin(self)

    def rend(self):
        return _H2ONaCl.ConstCharVector_rend(self)

    def clear(self):
        return _H2ONaCl.ConstCharVector_clear(self)

    def get_allocator(self):
        return _H2ONaCl.ConstCharVector_get_allocator(self)

    def pop_back(self):
        return _H2ONaCl.ConstCharVector_pop_back(self)

    def erase(self, *args):
        return _H2ONaCl.ConstCharVector_erase(self, *args)

    def __init__(self, *args):
        _H2ONaCl.ConstCharVector_swiginit(self, _H2ONaCl.new_ConstCharVector(*args))

    def push_back(self, x):
        return _H2ONaCl.ConstCharVector_push_back(self, x)

    def front(self):
        return _H2ONaCl.ConstCharVector_front(self)

    def back(self):
        return _H2ONaCl.ConstCharVector_back(self)

    def assign(self, n, x):
        return _H2ONaCl.ConstCharVector_assign(self, n, x)

    def resize(self, *args):
        return _H2ONaCl.ConstCharVector_resize(self, *args)

    def insert(self, *args):
        return _H2ONaCl.ConstCharVector_insert(self, *args)

    def reserve(self, n):
        return _H2ONaCl.ConstCharVector_reserve(self, n)

    def capacity(self):
        return _H2ONaCl.ConstCharVector_capacity(self)
    __swig_destroy__ = _H2ONaCl.delete_ConstCharVector

# Register ConstCharVector in _H2ONaCl:
_H2ONaCl.ConstCharVector_swigregister(ConstCharVector)

fmt_vtk = _H2ONaCl.fmt_vtk
fmt_dat = _H2ONaCl.fmt_dat
SinglePhase_L = _H2ONaCl.SinglePhase_L
TwoPhase_L_V_X0 = _H2ONaCl.TwoPhase_L_V_X0
SinglePhase_V = _H2ONaCl.SinglePhase_V
TwoPhase_L_H = _H2ONaCl.TwoPhase_L_H
TwoPhase_V_H = _H2ONaCl.TwoPhase_V_H
ThreePhase_V_L_H = _H2ONaCl.ThreePhase_V_L_H
TwoPhase_V_L_L = _H2ONaCl.TwoPhase_V_L_L
TwoPhase_V_L_V = _H2ONaCl.TwoPhase_V_L_V
class PROP_H2ONaCl(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    Region = property(_H2ONaCl.PROP_H2ONaCl_Region_get, _H2ONaCl.PROP_H2ONaCl_Region_set)
    T = property(_H2ONaCl.PROP_H2ONaCl_T_get, _H2ONaCl.PROP_H2ONaCl_T_set)
    H = property(_H2ONaCl.PROP_H2ONaCl_H_get, _H2ONaCl.PROP_H2ONaCl_H_set)
    Rho = property(_H2ONaCl.PROP_H2ONaCl_Rho_get, _H2ONaCl.PROP_H2ONaCl_Rho_set)
    Mu = property(_H2ONaCl.PROP_H2ONaCl_Mu_get, _H2ONaCl.PROP_H2ONaCl_Mu_set)
    Rho_l = property(_H2ONaCl.PROP_H2ONaCl_Rho_l_get, _H2ONaCl.PROP_H2ONaCl_Rho_l_set)
    Rho_v = property(_H2ONaCl.PROP_H2ONaCl_Rho_v_get, _H2ONaCl.PROP_H2ONaCl_Rho_v_set)
    Rho_h = property(_H2ONaCl.PROP_H2ONaCl_Rho_h_get, _H2ONaCl.PROP_H2ONaCl_Rho_h_set)
    H_l = property(_H2ONaCl.PROP_H2ONaCl_H_l_get, _H2ONaCl.PROP_H2ONaCl_H_l_set)
    H_v = property(_H2ONaCl.PROP_H2ONaCl_H_v_get, _H2ONaCl.PROP_H2ONaCl_H_v_set)
    H_h = property(_H2ONaCl.PROP_H2ONaCl_H_h_get, _H2ONaCl.PROP_H2ONaCl_H_h_set)
    S_l = property(_H2ONaCl.PROP_H2ONaCl_S_l_get, _H2ONaCl.PROP_H2ONaCl_S_l_set)
    S_v = property(_H2ONaCl.PROP_H2ONaCl_S_v_get, _H2ONaCl.PROP_H2ONaCl_S_v_set)
    S_h = property(_H2ONaCl.PROP_H2ONaCl_S_h_get, _H2ONaCl.PROP_H2ONaCl_S_h_set)
    X_l = property(_H2ONaCl.PROP_H2ONaCl_X_l_get, _H2ONaCl.PROP_H2ONaCl_X_l_set)
    X_v = property(_H2ONaCl.PROP_H2ONaCl_X_v_get, _H2ONaCl.PROP_H2ONaCl_X_v_set)
    Mu_l = property(_H2ONaCl.PROP_H2ONaCl_Mu_l_get, _H2ONaCl.PROP_H2ONaCl_Mu_l_set)
    Mu_v = property(_H2ONaCl.PROP_H2ONaCl_Mu_v_get, _H2ONaCl.PROP_H2ONaCl_Mu_v_set)

    def __init__(self):
        _H2ONaCl.PROP_H2ONaCl_swiginit(self, _H2ONaCl.new_PROP_H2ONaCl())
    __swig_destroy__ = _H2ONaCl.delete_PROP_H2ONaCl

# Register PROP_H2ONaCl in _H2ONaCl:
_H2ONaCl.PROP_H2ONaCl_swigregister(PROP_H2ONaCl)

class MP_STRUCT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    b1 = property(_H2ONaCl.MP_STRUCT_b1_get, _H2ONaCl.MP_STRUCT_b1_set)
    b1t = property(_H2ONaCl.MP_STRUCT_b1t_get, _H2ONaCl.MP_STRUCT_b1t_set)
    b1tt = property(_H2ONaCl.MP_STRUCT_b1tt_get, _H2ONaCl.MP_STRUCT_b1tt_set)
    b2 = property(_H2ONaCl.MP_STRUCT_b2_get, _H2ONaCl.MP_STRUCT_b2_set)
    b2t = property(_H2ONaCl.MP_STRUCT_b2t_get, _H2ONaCl.MP_STRUCT_b2t_set)
    b2tt = property(_H2ONaCl.MP_STRUCT_b2tt_get, _H2ONaCl.MP_STRUCT_b2tt_set)

    def __init__(self):
        _H2ONaCl.MP_STRUCT_swiginit(self, _H2ONaCl.new_MP_STRUCT())
    __swig_destroy__ = _H2ONaCl.delete_MP_STRUCT

# Register MP_STRUCT in _H2ONaCl:
_H2ONaCl.MP_STRUCT_swigregister(MP_STRUCT)

class ID_STRUCT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    f = property(_H2ONaCl.ID_STRUCT_f_get, _H2ONaCl.ID_STRUCT_f_set)
    ft = property(_H2ONaCl.ID_STRUCT_ft_get, _H2ONaCl.ID_STRUCT_ft_set)
    ftt = property(_H2ONaCl.ID_STRUCT_ftt_get, _H2ONaCl.ID_STRUCT_ftt_set)

    def __init__(self):
        _H2ONaCl.ID_STRUCT_swiginit(self, _H2ONaCl.new_ID_STRUCT())
    __swig_destroy__ = _H2ONaCl.delete_ID_STRUCT

# Register ID_STRUCT in _H2ONaCl:
_H2ONaCl.ID_STRUCT_swigregister(ID_STRUCT)

class TWOPHASEPROP_STRUCT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    f = property(_H2ONaCl.TWOPHASEPROP_STRUCT_f_get, _H2ONaCl.TWOPHASEPROP_STRUCT_f_set)
    p = property(_H2ONaCl.TWOPHASEPROP_STRUCT_p_get, _H2ONaCl.TWOPHASEPROP_STRUCT_p_set)
    s = property(_H2ONaCl.TWOPHASEPROP_STRUCT_s_get, _H2ONaCl.TWOPHASEPROP_STRUCT_s_set)
    g = property(_H2ONaCl.TWOPHASEPROP_STRUCT_g_get, _H2ONaCl.TWOPHASEPROP_STRUCT_g_set)
    u = property(_H2ONaCl.TWOPHASEPROP_STRUCT_u_get, _H2ONaCl.TWOPHASEPROP_STRUCT_u_set)
    h = property(_H2ONaCl.TWOPHASEPROP_STRUCT_h_get, _H2ONaCl.TWOPHASEPROP_STRUCT_h_set)
    dpd = property(_H2ONaCl.TWOPHASEPROP_STRUCT_dpd_get, _H2ONaCl.TWOPHASEPROP_STRUCT_dpd_set)
    dpt = property(_H2ONaCl.TWOPHASEPROP_STRUCT_dpt_get, _H2ONaCl.TWOPHASEPROP_STRUCT_dpt_set)
    cv = property(_H2ONaCl.TWOPHASEPROP_STRUCT_cv_get, _H2ONaCl.TWOPHASEPROP_STRUCT_cv_set)
    x = property(_H2ONaCl.TWOPHASEPROP_STRUCT_x_get, _H2ONaCl.TWOPHASEPROP_STRUCT_x_set)

    def __init__(self):
        _H2ONaCl.TWOPHASEPROP_STRUCT_swiginit(self, _H2ONaCl.new_TWOPHASEPROP_STRUCT())
    __swig_destroy__ = _H2ONaCl.delete_TWOPHASEPROP_STRUCT

# Register TWOPHASEPROP_STRUCT in _H2ONaCl:
_H2ONaCl.TWOPHASEPROP_STRUCT_swigregister(TWOPHASEPROP_STRUCT)

class BS_STRUCT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    x = property(_H2ONaCl.BS_STRUCT_x_get, _H2ONaCl.BS_STRUCT_x_set)
    f = property(_H2ONaCl.BS_STRUCT_f_get, _H2ONaCl.BS_STRUCT_f_set)
    fd = property(_H2ONaCl.BS_STRUCT_fd_get, _H2ONaCl.BS_STRUCT_fd_set)
    fdd = property(_H2ONaCl.BS_STRUCT_fdd_get, _H2ONaCl.BS_STRUCT_fdd_set)
    ft = property(_H2ONaCl.BS_STRUCT_ft_get, _H2ONaCl.BS_STRUCT_ft_set)
    ftd = property(_H2ONaCl.BS_STRUCT_ftd_get, _H2ONaCl.BS_STRUCT_ftd_set)
    ftt = property(_H2ONaCl.BS_STRUCT_ftt_get, _H2ONaCl.BS_STRUCT_ftt_set)

    def __init__(self):
        _H2ONaCl.BS_STRUCT_swiginit(self, _H2ONaCl.new_BS_STRUCT())
    __swig_destroy__ = _H2ONaCl.delete_BS_STRUCT

# Register BS_STRUCT in _H2ONaCl:
_H2ONaCl.BS_STRUCT_swigregister(BS_STRUCT)

class RS_STRUCT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    f = property(_H2ONaCl.RS_STRUCT_f_get, _H2ONaCl.RS_STRUCT_f_set)
    ft = property(_H2ONaCl.RS_STRUCT_ft_get, _H2ONaCl.RS_STRUCT_ft_set)
    ftd = property(_H2ONaCl.RS_STRUCT_ftd_get, _H2ONaCl.RS_STRUCT_ftd_set)
    fd = property(_H2ONaCl.RS_STRUCT_fd_get, _H2ONaCl.RS_STRUCT_fd_set)
    fdd = property(_H2ONaCl.RS_STRUCT_fdd_get, _H2ONaCl.RS_STRUCT_fdd_set)
    ftt = property(_H2ONaCl.RS_STRUCT_ftt_get, _H2ONaCl.RS_STRUCT_ftt_set)

    def __init__(self):
        _H2ONaCl.RS_STRUCT_swiginit(self, _H2ONaCl.new_RS_STRUCT())
    __swig_destroy__ = _H2ONaCl.delete_RS_STRUCT

# Register RS_STRUCT in _H2ONaCl:
_H2ONaCl.RS_STRUCT_swigregister(RS_STRUCT)

class Cr_STRUCT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    g = property(_H2ONaCl.Cr_STRUCT_g_get, _H2ONaCl.Cr_STRUCT_g_set)
    k = property(_H2ONaCl.Cr_STRUCT_k_get, _H2ONaCl.Cr_STRUCT_k_set)
    l = property(_H2ONaCl.Cr_STRUCT_l_get, _H2ONaCl.Cr_STRUCT_l_set)
    gg = property(_H2ONaCl.Cr_STRUCT_gg_get, _H2ONaCl.Cr_STRUCT_gg_set)
    t = property(_H2ONaCl.Cr_STRUCT_t_get, _H2ONaCl.Cr_STRUCT_t_set)
    d = property(_H2ONaCl.Cr_STRUCT_d_get, _H2ONaCl.Cr_STRUCT_d_set)
    a = property(_H2ONaCl.Cr_STRUCT_a_get, _H2ONaCl.Cr_STRUCT_a_set)
    b = property(_H2ONaCl.Cr_STRUCT_b_get, _H2ONaCl.Cr_STRUCT_b_set)

    def __init__(self):
        _H2ONaCl.Cr_STRUCT_swiginit(self, _H2ONaCl.new_Cr_STRUCT())
    __swig_destroy__ = _H2ONaCl.delete_Cr_STRUCT

# Register Cr_STRUCT in _H2ONaCl:
_H2ONaCl.Cr_STRUCT_swigregister(Cr_STRUCT)

class f_STRUCT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    f = property(_H2ONaCl.f_STRUCT_f_get, _H2ONaCl.f_STRUCT_f_set)
    sum_f10 = property(_H2ONaCl.f_STRUCT_sum_f10_get, _H2ONaCl.f_STRUCT_sum_f10_set)

    def __init__(self):
        _H2ONaCl.f_STRUCT_swiginit(self, _H2ONaCl.new_f_STRUCT())
    __swig_destroy__ = _H2ONaCl.delete_f_STRUCT

# Register f_STRUCT in _H2ONaCl:
_H2ONaCl.f_STRUCT_swigregister(f_STRUCT)

class cH2ONaCl(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _H2ONaCl.cH2ONaCl_swiginit(self, _H2ONaCl.new_cH2ONaCl())
    __swig_destroy__ = _H2ONaCl.delete_cH2ONaCl
    m_water = property(_H2ONaCl.cH2ONaCl_m_water_get, _H2ONaCl.cH2ONaCl_m_water_set)
    m_NaCl = property(_H2ONaCl.cH2ONaCl_m_NaCl_get, _H2ONaCl.cH2ONaCl_m_NaCl_set)
    m_phaseRegion_name = property(_H2ONaCl.cH2ONaCl_m_phaseRegion_name_get, _H2ONaCl.cH2ONaCl_m_phaseRegion_name_set)
    m_prop = property(_H2ONaCl.cH2ONaCl_m_prop_get, _H2ONaCl.cH2ONaCl_m_prop_set)

    def getPhaseRegionName(self, regionID):
        return _H2ONaCl.cH2ONaCl_getPhaseRegionName(self, regionID)

    def prop_pTX(self, p, T_K, X_wt, visc_on=True):
        return _H2ONaCl.cH2ONaCl_prop_pTX(self, p, T_K, X_wt, visc_on)

    def prop_pHX(self, p, H, X_wt):
        return _H2ONaCl.cH2ONaCl_prop_pHX(self, p, H, X_wt)

    def rho_pTX(self, p, T_K, X_wt):
        return _H2ONaCl.cH2ONaCl_rho_pTX(self, p, T_K, X_wt)

    def rho_l_pTX(self, p, T_K, X_wt):
        return _H2ONaCl.cH2ONaCl_rho_l_pTX(self, p, T_K, X_wt)

    def mu_l_pTX(self, p, T_K, X_wt):
        return _H2ONaCl.cH2ONaCl_mu_l_pTX(self, p, T_K, X_wt)

    def mu_pTX(self, p, T_K, X_wt):
        return _H2ONaCl.cH2ONaCl_mu_pTX(self, p, T_K, X_wt)

    def writeProps2VTK(self, *args):
        return _H2ONaCl.cH2ONaCl_writeProps2VTK(self, *args)

    def writeProps2xyz(self, *args):
        return _H2ONaCl.cH2ONaCl_writeProps2xyz(self, *args)

    def setColorPrint(self, colorPrint):
        return _H2ONaCl.cH2ONaCl_setColorPrint(self, colorPrint)

    def checkTemperatureRange(self, temperature_C):
        return _H2ONaCl.cH2ONaCl_checkTemperatureRange(self, temperature_C)

    def checkPressureRange(self, pressure_bar):
        return _H2ONaCl.cH2ONaCl_checkPressureRange(self, pressure_bar)

    def checkSalinityRange(self, salinity):
        return _H2ONaCl.cH2ONaCl_checkSalinityRange(self, salinity)

    def CheckRange_H(self, H0, P0, X0):
        return _H2ONaCl.cH2ONaCl_CheckRange_H(self, H0, P0, X0)

    def CheckRanges_H_PX(self, HMIN0, HMAX0, PXrange):
        return _H2ONaCl.cH2ONaCl_CheckRanges_H_PX(self, HMIN0, HMAX0, PXrange)

    def CheckRanges_H_P(self, HMIN0, HMAX0, Prange, X0):
        return _H2ONaCl.cH2ONaCl_CheckRanges_H_P(self, HMIN0, HMAX0, Prange, X0)

    def CheckRanges_H_X(self, HMIN0, HMAX0, Xrange, P0):
        return _H2ONaCl.cH2ONaCl_CheckRanges_H_X(self, HMIN0, HMAX0, Xrange, P0)

    def P_X_Critical(self, T):
        return _H2ONaCl.cH2ONaCl_P_X_Critical(self, T)

    def T_Critical(self, P):
        return _H2ONaCl.cH2ONaCl_T_Critical(self, P)

    def writeCriticalCurve(self, *args):
        return _H2ONaCl.cH2ONaCl_writeCriticalCurve(self, *args)

    def writeNaClMeltingCurve(self, *args):
        return _H2ONaCl.cH2ONaCl_writeNaClMeltingCurve(self, *args)

    def writeVaporLiquidHalite_V_L_H_Curve(self, *args):
        return _H2ONaCl.cH2ONaCl_writeVaporLiquidHalite_V_L_H_Curve(self, *args)

    def writeH2OBoilingCurve(self, *args):
        return _H2ONaCl.cH2ONaCl_writeH2OBoilingCurve(self, *args)

    def X_HaliteLiquidus(self, *args):
        return _H2ONaCl.cH2ONaCl_X_HaliteLiquidus(self, *args)

    def writeHaliteLiquidusSurface(self, *args):
        return _H2ONaCl.cH2ONaCl_writeHaliteLiquidusSurface(self, *args)

    def X_VaporHaliteCoexist(self, T, P):
        return _H2ONaCl.cH2ONaCl_X_VaporHaliteCoexist(self, T, P)

    def P_VaporLiquidHaliteCoexist(self, T):
        return _H2ONaCl.cH2ONaCl_P_VaporLiquidHaliteCoexist(self, T)

    def T_VaporLiquidHaliteCoexist(self, P):
        return _H2ONaCl.cH2ONaCl_T_VaporLiquidHaliteCoexist(self, P)

    def writeVaporLiquidHaliteCoexistSurface(self, *args):
        return _H2ONaCl.cH2ONaCl_writeVaporLiquidHaliteCoexistSurface(self, *args)

    def X_VaporLiquidCoexistSurface_LiquidBranch(self, *args):
        return _H2ONaCl.cH2ONaCl_X_VaporLiquidCoexistSurface_LiquidBranch(self, *args)

    def X_VaporLiquidCoexistSurface_VaporBranch(self, *args):
        return _H2ONaCl.cH2ONaCl_X_VaporLiquidCoexistSurface_VaporBranch(self, *args)

    def writeVaporLiquidCoexistSurface(self, *args):
        return _H2ONaCl.cH2ONaCl_writeVaporLiquidCoexistSurface(self, *args)

    def T_star_V(self, T, P, X):
        return _H2ONaCl.cH2ONaCl_T_star_V(self, T, P, X)

    def V_extrapol(self, T, P, X):
        return _H2ONaCl.cH2ONaCl_V_extrapol(self, T, P, X)

    def Wt2Mol(self, X_wt):
        return _H2ONaCl.cH2ONaCl_Wt2Mol(self, X_wt)

    def Mol2Wt(self, *args):
        return _H2ONaCl.cH2ONaCl_Mol2Wt(self, *args)

    def Rho_Br_for_V_extrapol(self, T, P, X):
        return _H2ONaCl.cH2ONaCl_Rho_Br_for_V_extrapol(self, T, P, X)

    def Rho_brine(self, T, P, X):
        return _H2ONaCl.cH2ONaCl_Rho_brine(self, T, P, X)

    def findPhaseRegion(self, T, P, X_wt, Xl_all, Xv_all):
        return _H2ONaCl.cH2ONaCl_findPhaseRegion(self, T, P, X_wt, Xl_all, Xv_all)

# Register cH2ONaCl in _H2ONaCl:
_H2ONaCl.cH2ONaCl_swigregister(cH2ONaCl)
cvar = _H2ONaCl.cvar
PMIN = cvar.PMIN
PMAX = cvar.PMAX
TMIN = cvar.TMIN
TMAX = cvar.TMAX
TMIN_K = cvar.TMIN_K
TMAX_K = cvar.TMAX_K
TMIN_C = cvar.TMIN_C
TMAX_C = cvar.TMAX_C
XMIN = cvar.XMIN
XMAX = cvar.XMAX






from pyswEOS import H2ONaCl
from pyswEOS import H2O
water=H2O.cH2O()
sw=H2ONaCl.cH2ONaCl()
# 1. function
print(sw.Rho_brine(300, 200, 0.2))
print(sw.P_VaporLiquidHaliteCoexist(200))
# 2. function with multi returns
p_crit,x_crit=sw.P_X_Critical(800)
print(p_crit,x_crit,sw.Mol2Wt(x_crit)*100)
# 3. constants
print(H2ONaCl.TMAX)
# 4. 
print(water.P_Boiling(200))

# 5. calculate properties
prop=sw.prop_pHX(100E5, 2E6, 0.5)
print(prop.T,sw.getPhaseRegionName(prop.Region))
prop=sw.prop_pTX(100E5, 100+273.15, 0.5)
print(prop.H,sw.getPhaseRegionName(prop.Region))


# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _H2O
else:
    import _H2O

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class Table62(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    numCoeff = _H2O.Table62_numCoeff
    c = property(_H2O.Table62_c_get, _H2O.Table62_c_set)
    d = property(_H2O.Table62_d_get, _H2O.Table62_d_set)
    t = property(_H2O.Table62_t_get, _H2O.Table62_t_set)
    n = property(_H2O.Table62_n_get, _H2O.Table62_n_set)
    alpha = property(_H2O.Table62_alpha_get, _H2O.Table62_alpha_set)
    beta = property(_H2O.Table62_beta_get, _H2O.Table62_beta_set)
    gamma = property(_H2O.Table62_gamma_get, _H2O.Table62_gamma_set)
    epsilon = property(_H2O.Table62_epsilon_get, _H2O.Table62_epsilon_set)
    a = property(_H2O.Table62_a_get, _H2O.Table62_a_set)
    b = property(_H2O.Table62_b_get, _H2O.Table62_b_set)
    A = property(_H2O.Table62_A_get, _H2O.Table62_A_set)
    B = property(_H2O.Table62_B_get, _H2O.Table62_B_set)
    C = property(_H2O.Table62_C_get, _H2O.Table62_C_set)
    D = property(_H2O.Table62_D_get, _H2O.Table62_D_set)

    def __init__(self):
        _H2O.Table62_swiginit(self, _H2O.new_Table62())
    __swig_destroy__ = _H2O.delete_Table62

# Register Table62 in _H2O:
_H2O.Table62_swigregister(Table62)

class Table61(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    n0 = property(_H2O.Table61_n0_get, _H2O.Table61_n0_set)
    gamma0 = property(_H2O.Table61_gamma0_get, _H2O.Table61_gamma0_set)

    def __init__(self):
        _H2O.Table61_swiginit(self, _H2O.new_Table61())
    __swig_destroy__ = _H2O.delete_Table61

# Register Table61 in _H2O:
_H2O.Table61_swigregister(Table61)

iceI = _H2O.iceI
iceIII = _H2O.iceIII
iceV = _H2O.iceV
iceVI = _H2O.iceVI
iceVII = _H2O.iceVII
class cH2O(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _H2O.cH2O_swiginit(self, _H2O.new_cH2O())
    __swig_destroy__ = _H2O.delete_cH2O

    def P_Boiling(self, T):
        return _H2O.cH2O_P_Boiling(self, T)

    def Rho_Liquid_Saturated(self, T):
        return _H2O.cH2O_Rho_Liquid_Saturated(self, T)

    def Rho_Vapor_Saturated(self, T):
        return _H2O.cH2O_Rho_Vapor_Saturated(self, T)

    def Rho(self, T, P):
        return _H2O.cH2O_Rho(self, T, P)

    def Phi_r_delta(self, delta, tau):
        return _H2O.cH2O_Phi_r_delta(self, delta, tau)

    def Phi_o_tau(self, delta, tau):
        return _H2O.cH2O_Phi_o_tau(self, delta, tau)

    def Phi_r_tau(self, delta, tau):
        return _H2O.cH2O_Phi_r_tau(self, delta, tau)

    def Pressure_T_Rho(self, T, Rho):
        return _H2O.cH2O_Pressure_T_Rho(self, T, Rho)

    def SublimationCurve(self, T):
        return _H2O.cH2O_SublimationCurve(self, T)

    def BoilingCurve(self, T):
        return _H2O.cH2O_BoilingCurve(self, T)

    def MeltingCurve(self, T, isIceI=False):
        return _H2O.cH2O_MeltingCurve(self, T, isIceI)

    def SpecificEnthalpy_T_Rho(self, T, Rho):
        return _H2O.cH2O_SpecificEnthalpy_T_Rho(self, T, Rho)

    def SpecificEnthalpy(self, T, P):
        return _H2O.cH2O_SpecificEnthalpy(self, T, P)

# Register cH2O in _H2O:
_H2O.cH2O_swigregister(cH2O)
cvar = _H2O.cvar
PMIN = cvar.PMIN
PMAX = cvar.PMAX
TMIN = cvar.TMIN
TMAX = cvar.TMAX
T_Critic_K = cvar.T_Critic_K
P_Critic = cvar.P_Critic
T_Critic = cvar.T_Critic
Rho_Critic = cvar.Rho_Critic
MolarMass = cvar.MolarMass
T_Triple_K = cvar.T_Triple_K
T_Triple = cvar.T_Triple
P_Triple = cvar.P_Triple
Rho_Triple_liquid = cvar.Rho_Triple_liquid
Rho_Triple_vapor = cvar.Rho_Triple_vapor
T_K_ice_min = cvar.T_K_ice_min
T_K_ice_max = cvar.T_K_ice_max
R_const = cvar.R_const






#!python
# -*-coding:utf-8-*-
# Calculate phase diagram and thermal dynamic properties of NaCl-H2O system in 2D space
# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# 'Zhikui Guo, 2021/01/05, GEOMAR
# ===============================================================

import sys
import argparse
import os
#===============================================================
import numpy as np 
import matplotlib as mpl
import matplotlib.pyplot as plt
# config font
mpl.rcParams['font.family'] = 'Arial'
mpl.rcParams['font.size'] = 12
mpl.rcParams['mathtext.fontset'] = 'cm'
sec_year=86400*365
cm2inch=1 #0.393701
dpi=600

from pyswEOS import H2ONaCl
from pyswEOS import H2O
# water=H2O.cH2O()
# sw=H2ONaCl.cH2ONaCl()
fmt_figs=['pdf']
dpi=400
def usage(argv):
    basename = argv[0].split('/')
    basename = basename[len(basename)-1]
    description='Calculate phase diagram and thermal dynamic properties of NaCl-H2O system in 2D space'
    num_symbol=int((len(description)+20 - len(basename))/2)
    head='='*num_symbol+basename+'='*num_symbol
    print(head)
    print(description)
    print('Zhikui Guo, 2021/01/05, GEOMAR')
    print('[Example]: '+C_RED + basename+C_BLUE + ' example usage'+C_DEFAULT)
    print('='*len(head))

def XT_P0(P0=500, Xmin=1E-5, Xmax=0.999999, Tmin=1, Tmax=1000, nX=100, nT=100):
    """Calculate phase diagram and properties in X-T space 
    with given P

    Args:
        P0 (float, optional): Pressure [bar]. Defaults to 100.
        Xmin (float, optional): Min salinity [wt% NaCl]. Defaults to 0.
        Xmax (float, optional): Max salinity [wt% NaCl]. Defaults to 1.
        Tmin (float, optional): Min temperature [deg. C]. Defaults to 0.
        Tmax (float, optional): Max temperature [deg. C]. Defaults to 500.
    """

    sw=H2ONaCl.cH2ONaCl()
    T=np.linspace(Tmin, Tmax, nT)
    X=np.linspace(Xmin, Xmax, nX)
    P_vlh=np.zeros_like(T)
    T_vlh=np.array(sw.T_VaporLiquidHaliteCoexist(P0))
    X_LH=np.zeros_like(T)
    # 1. NaCl liquidus, only valid when P > P_{V+L+H}
    for i in range(0,len(T)):
        P_vlh[i] = sw.P_VaporLiquidHaliteCoexist(T[i]);
    if(P0>389):
        T_vlh=[]
    # plot
    # fig=plt.figure()
    fig,axes=plt.subplots(1,2,gridspec_kw={"width_ratios":[1,1],'wspace':0.1},figsize=(12,5))
    ax_T,ax_H=axes[0],axes[1]
    ax_H.yaxis.set_ticks_position('right')
    ax_H.yaxis.set_label_position('right')
    # 1. V+L+H
    if(len(T_vlh)==2):
        ax_T.axhspan(T_vlh[0],T_vlh[1],color='lightgray',alpha=0.5)
        T_vlh[0]=T_vlh[0]-1 # remove computation error, ensure it doesn't go cross LVH region
        T_vlh[1]=T_vlh[1]+1
    # region contourf in PTX space
    # XX,TT=np.meshgrid(X,T)
    # Regions_T=np.zeros_like(XX)
    # for i in range(0,len(T)):
    #     for j in range(0,len(X)):
    #         prop=sw.prop_pTX(P0*1E5, T[i]+273.15, X[j])
    #         Regions_T[i][j]=prop.Region
    # ax_T.contourf(XX,TT, Regions_T, levels=50)
    # region contourf in PHX space
    # H=np.linspace(1E-3,4,100)
    # XX,HH=np.meshgrid(X,H)
    # Regions=np.zeros_like(XX)
    # for i in range(0,len(H)):
    #     for j in range(0,len(X)):
    #         prop=sw.prop_pHX(P0*1E5, H[i]*1E6, X[j])
    #         Regions[i][j]=prop.Region
    # ax_H.contourf(XX,HH, Regions, levels=50)
    # 2. L+H
    if(len(T_vlh)==2):
        # segment 1
        # PTX space
        T_LH1=np.linspace(Tmin, T_vlh[0], 50)
        X_LH1=sw.Mol2Wt(sw.X_HaliteLiquidus(T_LH1, T_LH1*0+P0))
        l_LH,=ax_T.plot(X_LH1,T_LH1, color='g')
        # LVH point
        p_LVH,=ax_T.plot(X_LH1[-1],T_LH1[-1],marker='o',mfc='orange',mec='blue',label='LVH')
        H_LH1=np.zeros_like(T_LH1)
        for i in range(0,len(T_LH1)):
            prop=sw.prop_pTX(P0*1E5, T_LH1[i]+273.15, X_LH1[i])
            H_LH1[i]=prop.H
        # PHX space
        ax_H.plot(X_LH1,H_LH1/1E6,color=l_LH.get_color())
        prop=sw.prop_pHX(P0*1E5, H_LH1[-1], X_LH1[-1])
        # LVH region
        dH=1E4 #0.01 MJ/kg
        while(not prop.Region==5):
            prop=sw.prop_pHX(P0*1E5, H_LH1[-1]+dH, X_LH1[-1])
            dH+=1E4
            if(np.abs(dH)>1E5):
                break
        ax_H.fill([prop.X_l, prop.X_v, 1, prop.X_l], 
                np.array([prop.H_l, prop.H_v, prop.H_h, prop.H_l])/1E6,
                fc=p_LVH._markerfacecolor, ec=p_LVH._markeredgecolor, label='LVH')
        # segment 2
        T_LH2=np.linspace(T_vlh[1],Tmax, 50)
        X_LH2=np.array(sw.Mol2Wt(sw.X_HaliteLiquidus(T_LH2, T_LH2*0+P0)))
        ax_T.plot(X_LH2,T_LH2, color='g')
        # LVH point
        ax_T.plot(X_LH2[0],T_LH2[0],marker='o',mfc=p_LVH._markerfacecolor,mec=p_LVH._markeredgecolor)
        H_LH2=np.zeros_like(T_LH2)
        for i in range(0,len(T_LH2)):
            prop=sw.prop_pTX(P0*1E5, T_LH2[i]+273.15, X_LH2[i])
            H_LH2[i]=prop.H
        # PHX space
        ax_H.plot(X_LH2,H_LH2/1E6,color=l_LH.get_color(),marker='.')
        prop=sw.prop_pHX(P0*1E5, H_LH2[0], X_LH2[0])
        # LVH region
        dX=0.005
        while(not prop.Region==5):
            prop=sw.prop_pHX(P0*1E5, H_LH2[0], X_LH2[0]+dX)
            # dH-=dH
            dX-=0.001
            if(np.abs(dX)>0.005):
                break
        ax_H.fill([prop.X_l, prop.X_v, 1, prop.X_l], 
                np.array([prop.H_l, prop.H_v, prop.H_h, prop.H_l])/1E6,
                fc=p_LVH._markerfacecolor, ec=p_LVH._markeredgecolor, label='LVH')
    else:
        X_LH=sw.Mol2Wt(sw.X_HaliteLiquidus(T, T*0+P0))
        l_LH,=ax_T.plot(X_LH,T,color='g')
        H_LH=np.zeros_like(T)
        for i in range(0,len(T)):
            prop=sw.prop_pTX(P0*1E5, T[i]+273.15, X_LH[i])
            H_LH[i]=prop.H
        ax_H.plot(X_LH,H_LH/1E6,color=l_LH.get_color())
    # 3. L+V
    if(len(T_vlh)==2):
        # segment 1
        T_LV1=np.linspace(Tmin,T_vlh[0],100)
        X_LV_L1=np.array(sw.Mol2Wt(sw.X_VaporLiquidCoexistSurface_LiquidBranch(T_LV1,T_LV1*0+P0)))
        X_LV_V=np.array(sw.Mol2Wt(sw.X_VaporLiquidCoexistSurface_VaporBranch(T_LV1,T_LV1*0+P0)))
        ax_T.plot(X_LV_L1, T_LV1)
        ax_T.plot(X_LV_V, T_LV1)
    
        # segment 2
        T_LV2=np.linspace(T_vlh[1],Tmax,100)
        X_LV_L2=np.array(sw.Mol2Wt(sw.X_VaporLiquidCoexistSurface_LiquidBranch(T_LV2,T_LV2*0+P0)))
        ax_T.plot(X_LV_L2, T_LV2)
    else:
        X_LV_L=np.array(sw.Mol2Wt(sw.X_VaporLiquidCoexistSurface_LiquidBranch(T,T*0+P0)))
        X_LV_V=np.array(sw.Mol2Wt(sw.X_VaporLiquidCoexistSurface_VaporBranch(T,T*0+P0)))
        l_LV_L,=ax_T.plot(X_LV_L, T, color='k')
        l_LV_V,=ax_T.plot(X_LV_V, T, color='red')

        H_LV_L=np.zeros_like(T)
        H_LV_V=np.zeros_like(T)
        for i in range(0,len(T)):
            prop=sw.prop_pTX(P0*1E5, T[i]+273.15, X_LV_L[i])
            H_LV_L[i]=prop.H
            prop=sw.prop_pTX(P0*1E5, T[i]+273.15, X_LV_V[i])
            H_LV_V[i]=prop.H
        ax_H.plot(X_LV_L,H_LV_L/1E6,color=l_LV_L.get_color())
        ax_H.plot(X_LV_V,H_LV_V/1E6,color=l_LV_V.get_color())
    # axis
    for ax in axes:
        ax.set_xlim(Xmin, Xmax)
        ax.set_xlabel('Salinity (wt% NaCl)')
        ticks=ax.get_xticks()
        ax.xaxis.set_ticks(ticks)
        labels=[]
        for tick in ticks:
            labels.append(str('%.0f'%(tick*100)))
        ax.xaxis.set_ticklabels(labels)
    ax_T.set_ylim(Tmin,Tmax)
    ax_T.set_ylabel('Temperature ($^{\circ}$C)')
    ax_H.set_ylabel('Specific enthalpy (MJ/kg)')
    ax_H.set_ylim(0,4)

    plt.subplots_adjust(left=0.1,right=0.9,bottom=0.1,top=0.98)
    for fmt in fmt_figs:
        plt.savefig('PhaseDiagram_XT_P0.%s'%(fmt), dpi=dpi)
    # plt.show()

def main(argv):
    # argc=len(argv)
    # usage(argv)
    # exit(0)

    XT_P0()

if __name__ == '__main__':
    sys.exit(main(sys.argv))


#!/usr/bin/env python
# coding: utf-8

from setuptools import setup, find_packages

setup(
    name='pyswEOS',
    version='0.0.7',
    author='Zhikui Guo',
    author_email='zguo@geomar.de',
    url='https://www.scibyte.cn',
    description=u'Python API of swEOS library which is designed to calculate EOS and thermal dynamic properties of H2O-NaCl system, usually called salt water.',
    packages=find_packages(where='.', exclude=('docs_pyH2ONaCl'), include=('*',)), 
    install_requires=[
        'matplotlib',
        'numpy',
        'argparse',
        'colored'
        ],
    include_package_data=True,
    entry_points={
        'console_scripts': []
    },
    keywords = "NaCl H2O IAPWS Hydrothermal seawater"
)